@@ -148,9 +148,9 @@ impl_createView (PortableServer_Servant servant,
 		 CORBA_Environment *ev)
 {
 	EComponentView *component_view = e_component_view_new_controls (parent, "exchange",
-                                                        		NULL,
 									NULL,
-                                                        		NULL);
+									NULL,
+									NULL);
 	d(printf("createView...\n"));
 
         return BONOBO_OBJREF(component_view);
@@ -166,7 +166,7 @@ impl_upgradeFromVersion (PortableServer_Servant servant,
 	ExchangeComponent *component = EXCHANGE_COMPONENT (bonobo_object_from_servant (servant));
 	ExchangeAccount *account;
 	gchar *base_directory=NULL;
-	char *account_filename;
+	gchar *account_filename;
 
 	d(printf("upgradeFromVersion %d %d %d\n", major, minor, revision));
 
@@ -317,13 +317,13 @@ exchange_component_update_accounts (ExchangeComponent *component,
 }
 
 static void
-new_connection (MailStubListener *listener, int cmd_fd, int status_fd,
+new_connection (MailStubListener *listener, gint cmd_fd, gint status_fd,
 		ExchangeComponentAccount *baccount)
 {
 	MailStub *stub;
 	MailStubExchange *mse, *mse_prev;
 	ExchangeAccount *account = baccount->account;
-	int mode;
+	gint mode;
 
 	g_object_ref (account);
 
@@ -334,7 +334,7 @@ new_connection (MailStubListener *listener, int cmd_fd, int status_fd,
 	}
 
 	stub = mail_stub_exchange_new (account, cmd_fd, status_fd);
-	mse = (MailStubExchange *) stub; 
+	mse = (MailStubExchange *) stub;
 	mse_prev = (MailStubExchange *) listener->stub;
 	if (mse_prev) {
 		g_hash_table_destroy (mse->folders_by_name);
@@ -366,7 +366,7 @@ config_listener_account_created (ExchangeConfigListener *config_listener,
 	ExchangeComponent *component = user_data;
 	ExchangeComponentPrivate *priv = component->priv;
 	ExchangeComponentAccount *baccount;
-	char *path, *dot_exchange_username, *account_filename;
+	gchar *path, *dot_exchange_username, *account_filename;
 
 	baccount = g_new0 (ExchangeComponentAccount, 1);
 	baccount->account = g_object_ref (account);
@@ -434,7 +434,7 @@ exchange_component_class_init (ExchangeComponentClass *klass)
 	object_class->dispose = dispose;
 	object_class->finalize = finalize;
 
-	epv->createView     	= impl_createView;
+	epv->createView	= impl_createView;
 	epv->upgradeFromVersion = impl_upgradeFromVersion;
 	epv->requestQuit        = impl_requestQuit;
 	epv->quit               = impl_quit;
@@ -465,7 +465,7 @@ exchange_component_init (ExchangeComponent *component)
 
 	priv = component->priv = g_new0 (ExchangeComponentPrivate, 1);
 
-       	priv->config_listener = exchange_config_listener_new ();
+	priv->config_listener = exchange_config_listener_new ();
 	priv->comp_lock = g_mutex_new ();
 
 	g_signal_connect (priv->config_listener, "exchange_account_created",
@@ -494,7 +494,7 @@ exchange_component_new (void)
 
 ExchangeAccount *
 exchange_component_get_account_for_uri (ExchangeComponent *component,
-					const char *uri)
+					const gchar *uri)
 {
 	ExchangeComponentPrivate *priv = component->priv;
 	ExchangeComponentAccount *baccount;
@@ -522,7 +522,7 @@ exchange_component_get_account_for_uri (ExchangeComponent *component,
 }
 
 void
-exchange_component_is_offline (ExchangeComponent *component, int *state)
+exchange_component_is_offline (ExchangeComponent *component, gint *state)
 {
 	g_return_if_fail (EXCHANGE_IS_COMPONENT (component));
 
