@@ -7,10 +7,7 @@
 #include "exchange-types.h"
 #include "e-storage.h"
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 #define EXCHANGE_TYPE_STORAGE            (exchange_storage_get_type ())
 #define EXCHANGE_STORAGE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), EXCHANGE_TYPE_STORAGE, ExchangeStorage))
@@ -35,14 +32,12 @@ EStorage         *exchange_storage_new      (ExchangeAccount *account);
 
 #ifdef G_OS_WIN32
 
-extern const char *_exchange_storage_datadir;
-extern const char *_exchange_storage_gladedir;
-extern const char *_exchange_storage_imagesdir;
+extern const gchar *_exchange_storage_datadir;
+extern const gchar *_exchange_storage_gladedir;
+extern const gchar *_exchange_storage_imagesdir;
 
 #endif
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* __EXCHANGE_STORAGE_H__ */
